utils

package
v0.0.0-...-73d82be Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 2, 2019 License: Unlicense Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	Repositories = make(map[string]Repo)
	Debug        = false
)

Functions

func DefaultValue

func DefaultValue(val, fallback string) string

func ParseConfig

func ParseConfig(configPath string)

func Quote

func Quote(s string) string

Quote returns a shell-escaped version of the string s. The returned value is a string that can safely be used as one token in a shell command line.

Types

type Repo

type Repo struct {
	Path       string `ini:"path,omitempty"`
	Key        string `ini:"key,omitempty"`
	Script     string `ini:"script,omitempty"`
	Branch     string `ini:"branch,omitempty"`
	RemotePath string `ini:"remote_path,omitempty"`
}

Jump to