package
Version:
v0.0.0-...-73d82be
Opens a new window with list of versions in this module.
Published: Aug 2, 2019
License: Unlicense
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func ParseConfig(configPath string)
Quote returns a shell-escaped version of the string s. The returned value
is a string that can safely be used as one token in a shell command line.
type Repo struct {
Path string `ini:"path,omitempty"`
Key string `ini:"key,omitempty"`
Script string `ini:"script,omitempty"`
Branch string `ini:"branch,omitempty"`
RemotePath string `ini:"remote_path,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.